@@ -4,6 +4,8 @@ Dialog service - the central system of the Lilia chat bot.
 """
 
 GITHUB = "https://github.com"
-BOTTLE_SKILL_TEMPLATE_URL = GITHUB + "/PaperDevil/bottle-skill-template.git"
+BOTTLE_SKILL_TEMPLATE_URL = (
+        GITHUB + "/PaperDevil/bottle-skill-template/archive/develop.zip"
+)
 AIOHTTP_SKILL_TEMPLATE_URL = ""
 FAST_API_SKILL_TEMPLATE_URL = ""
\ No newline at end of file
