@@ -7,8 +7,11 @@ that are referenced in setup.py.
 """
 
 from sys import argv, version_info
-from os import getcwd
-from git import Repo
+from os import getcwd, remove, rename, listdir, path
+from shutil import move, rmtree
+from zipfile import ZipFile
+
+import requests
 
 from scintillant import BOTTLE_SKILL_TEMPLATE_URL
 from scintillant import AIOHTTP_SKILL_TEMPLATE_URL
@@ -40,8 +43,9 @@ def print_help(search_for: str = None):
           "with the 'Dialog' service - the central system of the "
           "Lilia chat bot. \n\n"
           "** Commands ** \n"
-          "- bottle - Download the latest skill template based on the "
-          "Bottle framework")
+          "+ bottle - Download the latest skill template based on the "
+          "Bottle framework\n"
+          ">> snlt bottle")
 
 
 def start_bottle_skill(skill_name: str = None):
@@ -49,9 +53,28 @@ def start_bottle_skill(skill_name: str = None):
     skill_name = input("Skill name: ") if not skill_name else skill_name
     skill_dirrectory = input(f"Skill directory ({skill_name}): ")
     if not skill_dirrectory:
-        skill_dirrectory = '.'
+        skill_dirrectory = skill_name
     print("Downloading project template...")
-    Repo.clone_from(BOTTLE_SKILL_TEMPLATE_URL, getcwd() + f'/{skill_dirrectory}')
+
+    r = requests.get(BOTTLE_SKILL_TEMPLATE_URL)
+    with open('temp.zip', 'wb') as f:
+        f.write(r.content)
+
+    with ZipFile('temp.zip', 'r') as repo_zip:
+        if skill_dirrectory == '.':
+            repo_zip.extractall()
+        else:
+            repo_zip.extractall('.')
+
+    remove('temp.zip')
+    if not skill_dirrectory == '.':
+        rename('bottle-skill-template-develop', skill_dirrectory)
+    else:
+        source = './bottle-skill-template-develop'
+        files = listdir(source)
+        for file in files:
+            move(source + f'/{file}', getcwd())
+        rmtree('./bottle-skill-template-develop')
 
     if not version_info < (3, 9):
         print("Language version below the required by the template")
